package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.boot.util.StringUtils;
import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileApplicationProviderService;
import com.seeyon.cip.connector.dto.mobile.MobileInterfaceStatusDto;
import com.seeyon.cip.connector.dto.mobile.MobileLaunchCodeDto;
import com.seeyon.cip.connector.dto.mobile.MobileMessageRequestDto;
import com.seeyon.cip.connector.dto.mobile.MobileOpenIdDto;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformRequestDto;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformSignatureDto;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformSignatureResultDto;
import com.seeyon.cip.connector.dto.mobile.MobilePublishAppRequestDto;
import com.seeyon.cip.connector.dto.mobile.MobileUrlDto;
import com.seeyon.cip.connector.dto.mobile.MobileUrlProviderDto;
import com.seeyon.cip.connector.dto.mobile.sso.MobileSsoUserDto;
import com.seeyon.cip.connector.dto.mobile.sso.MobileSsoUserRequestDto;

import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;

import lombok.extern.slf4j.Slf4j;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

/**
 * 应用功能接口实现
 *
 * @ConnectorChannelRouter 注解的值
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileApplicationProviderServiceImpl implements MobileApplicationProviderService {

    /**
     * 获取应用首页地址、PC端首页地址、移动端首页地址
     * <p>
     * MobileUrlProviderDto
     * String portalDomain;
     * String portalPath;
     * Map<String, String> mobilePathPara;   eg：{"mobile", 移动端地址}
     * Map<String, String> webPathPara;   eg：{"mobile", 移动端地址}
     * String corpId;
     * String appId;
     * String appKey;
     * String thirdApplicationDomain;  三方应用域名
     * String json; 自定义配置json
     * <p>
     * pageParam.put("mobile", frontBaseRoute + mobilePath);
     */
    @Override
    public MobileUrlDto getMobileUrlDto(MobileUrlProviderDto mobileUrlProviderDto) {

        // 1. web/mobile pathPara 编码
        /**
         * 变量初始化和数据处理
         *首先自定义formatParaMap() 方法来处理 mobileUrlProviderDto 中的移动路径参数和 Web 路径参数(注意： mobileUrlProviderDto 中的移动路径参数和 Web 路径参数为固定值)，将它们编码为字符串，并分别存储在 mobileQueryPath 和 webQueryPath 中
         * mobileQueryPath = "mobile=%2Fmain-mobile%2Fportal"
         * webQueryPath = "web=%2Fmain%2Fportal"
         */
        // eg. String mobileQueryPath = formatParaMap(mobileUrlProviderDto.getMobilePathPara());
        // eg. String webQueryPath = formatParaMap(mobileUrlProviderDto.getWebPathPara());

        // 通过 mobileUrlProviderDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = mobileUrlProviderDto.getCorpId());
        // eg. String appId = mobileUrlProviderDto.getAppId());

        // 构建不同的 URL。

        /**
         * 不同移动应用的URL具体格式不同：
         * 不需要重定向的URL格式：应用首页地址： https://mobileUrlProviderDto.getPortalDomain() + mobileUrlProviderDto.getPortalPath()?appId=....&corpId=.....&type=....&mobile=%2Fmain-mobile%2Fportal
         *                    桌面端地址： https://mobileUrlProviderDto.getPortalDomain() + mobileUrlProviderDto.getPortalPath()?appId=....&type=.....&web=%2Fmain%2Fportal
         *                              or  https://mobileUrlProviderDto.getPortalDomain() + mobileUrlProviderDto.getPortalPath()?appId=....&corpId=....&type=.....&web=%2Fmain%2Fportal
         *          *        移动端地址： https://mobileUrlProviderDto.getPortalDomain() + mobileUrlProviderDto.getPortalPath()?appId=....&corpId=....&Type=....&mobile=%2Fmain-mobile%2Fportal
         *
         */
        log.info("将拼接好的地址信息放到dto对象中返回");
        // 返回包含地址信息的dto对象
        // eg. return mobileUrlDto;

        MobileUrlDto mobileUrlDto = new MobileUrlDto();
        mobileUrlDto.setWebPortalUrl("webPortalUrl具体值");
        mobileUrlDto.setMobilePortalUrl("mobilePortalUrl具体值");
        mobileUrlDto.setPortalUrl("allPortalUrl具体值");
        return mobileUrlDto;
    }

    /**
     * 按需使用
     * 在运行配置界面可提供相关文档的跳转链接说明
     * eg. 前往 xx 开放平台，了解 ...
     */
    @Override
    public String explainLinkInfo() {

        return String.format("前往xx开放平台，了解<a href='%s' target='_blank'>《开发须知》</a>中关于<a href='%s' target='_blank'>《调用频率限制》" +
                "</a>的相关说明，更多详情请参考<a href='%s' target='_blank'>《关于企业内部应用API调用量和频次限制的调整说明》" +
                "。</a>登录<a href='%s' target='_blank'>xx开发者后台</a>,可查看API统计情况，并可申请提升限流。");
    }

    /**
     * 按需实现,如果移动插件提供了 可以通过接口发布应用，则需要实现。否则直接返回null
     *
     * @param mobilePublishAppRequestDto 移动应用发布需要的信息：应用名称、url地址等，
     * @param mobilePlatformConfigDto    配置信息：需要从这些信息中获取 appkey、appId、appSecret等信息来生成token
     * @return 如果发布成功则返回该应用的唯一标识
     */
    @Override
    public Long publishApp(MobilePublishAppRequestDto mobilePublishAppRequestDto, MobilePlatformConfigDto mobilePlatformConfigDto) {

        // 通过MobilePublishAppRequestDto信息拿到发布应用所需的各种细节，如应用图标、应用描述、移动端网址、PC端网址和应用名称等信息。
        // eg. String appDesc = mobilePublishAppRequestDto.getName();
        // eg. String mobileUrl = mobilePublishAppRequestDto.getMobileUrl();
        //构建 params 参数映射，包含发布应用所需的各种细节，如应用图标、应用描述、移动端网址、PC端网址和应用名称等信息。

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的发布应用接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getCreateUnitUri(token), body, DemoResponseDto.PublishApp.class);
        log.info("返回成功发布的应用的唯一标识");
        // eg. return result.getAgentid();
        return null;
    }

    /**
     * 按需实现
     * 实现了一个生成移动平台签名（signature）的方法 getSignature,用于验证调用接口的合法性和安全性
     */
    @Override
    public MobilePlatformSignatureResultDto getSignature(MobilePlatformConfigDto mobilePlatformConfigDto, MobilePlatformSignatureDto dto) {

        // 根据第三方配置信息和签名数据，调用移动应用的API获取ticket(具体获取ticket方式详见第三方文档)，然后根据特定规则生成签名，并封装成MobilePlatformSignatureResultDto对象返回。
        // eg.DemoResponseDto.Ticket ticket = getTicket(mobilePlatformRequestDto);
        /**
         * 创建 MobilePlatformSignatureResultDto 对象 resultDto，并设置其中的 corpId、agentId、noncestr、timestamp、type 等属性
         * ResultDto (MobilePlatformSignatureResultDto)：移动平台签名结果的数据传输对象，可能包含以下字段，具体按需返回：
         * corpId：企业ID
         * agentId：应用ID（代理ID）
         * noncestr：随机字符串（16位）
         * type：类型
         * timestamp：时间戳
         * signature：签名结果
         */
        MobilePlatformSignatureResultDto resultDto = new MobilePlatformSignatureResultDto();

        //  通过MobilePlatformSignatureResultDto对象的参数构建用于生成签名的原始字符串 plain
        // eg. String plain = "jsapi_ticket=" + ticket.getTicket() + ".........";
        // 使用 DigestUtil.sha256Hex 方法对 plain 字符串进行 SHA-256 散列，生成签名 sign
        // eg. String sign = DigestUtil.sha256Hex(plain);
        //设置签名结果
        // eg. resultDto.setSignature(sign);
        //返回签名结果对象
        return resultDto;
    }

    /**
     * 发送消息:用于发送消息到移动平台上 （核心）
     * 可以发送两种类型的消息：1.纯文本消息； 2.带链接的消息
     * 接收三个参数：
     * isActionCard：true: 带链接的消息； false:纯文本消息
     * mobileMessageRequestDto：移动消息请求的数据传输对象，包含了要发送的消息内容和接收用户信息
     * mobilePlatformRequestDto：移动平台请求的数据传输对象，包含了平台相关的配置信息
     */
    @Override
    public void sendMessage(boolean isActionCard, MobileMessageRequestDto mobileMessageRequestDto, MobilePlatformRequestDto mobilePlatformRequestDto) {
        /**
         * 用户信息验证
         * 首先检查 mobileMessageRequestDto 对象及其内部的用户信息是否为 null 或用户的 userId 是否为空或空白。如果满足这些条件，说明没有有效的用户信息可用于发送消息，因此记录一条日志并直接返回，不进行消息发送操作
         */
        if (null == mobileMessageRequestDto || null == mobileMessageRequestDto.getUser() || StringUtils.isBlank(mobileMessageRequestDto.getUser().getUserId())) {
            log.info("没有用户信息， 不需要发送消息, thirdPluginId:{}", mobilePlatformRequestDto.getId());
            return;
        }
        //如果用户信息有效，从 mobileMessageRequestDto 中获取用户的 userId
        // eg. String thirdUserId = mobileMessageRequestDto.getUser().getUserId();
        /**
         * 根据 isActionCard 的值决定调用哪种类型的消息发送方法：
         * 如果 isActionCard 为 true，则调用 sendActionCard 方法发送 ActionCard 类型的消息。
         * 如果 isActionCard 为 false，则调用 sendMarkdownMsg 方法发送 Markdown 格式的消息。
         */
        // 通过 mobileUrlProviderDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = mobileUrlProviderDto.getCorpId());
        // eg. String appId = mobileUrlProviderDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        if (isActionCard) {
            // 调用三方平台接口发送带链接的消息
            log.info("查看三方移动平台对应的发送消息的接口文档传入对应的 发送消息url、 消息内容 执行带链接的消息发送");
        } else {
            // 调用三方平台接口发送文本的消息
            log.info("查看三方移动平台对应的发送消息的接口文档传入对应的 发送消息url、 消息内容 执行带链接的消息发送");
        }
    }

    /**
     * 通过免登码获取用户信息,（核心）
     * 实现一登陆三方平台的用户可以免登进入我们在三方平台创建的应用
     *
     * @param mobilePlatformConfigDto 配置信息：需要从这些信息中获取 appkey、appId、appSecret等信息来生成token
     * @param mobileSsoQueryDto       移动单点登录查询的数据传输对象，包含登录所需的code和扩展数据extData
     * @return 移动单点登录用户数据的数据传输对象 三方平台免登用户信息：包含根据预登录或正常登录获取的用户信息
     */
    @Override
    public MobileSsoUserDto getMobileSsoUserDto(MobilePlatformConfigDto mobilePlatformConfigDto, MobileSsoUserRequestDto mobileSsoQueryDto) {
        MobileSsoUserDto mobileSsoUserDto = new MobileSsoUserDto();
        //通过三方移动平台文档查看是否需要建立用户映射关系，若不需要，则返回的用户信息中只需要在以下五个参数中选择一个进行返回即可
        mobileSsoUserDto.setThirdLoginName("zhangsan");
        mobileSsoUserDto.setThirdUserId("123456");
        mobileSsoUserDto.setThirdMobile("13900000001");
        mobileSsoUserDto.setThirdUserEmail("abc@abc.com");
        mobileSsoUserDto.setThirdUserCode("usercode");
        // 通过三方移动平台文档查看是否需要建立用户映射关系，以及需要与哪个字段做映射。若需要建立用户映射，则返回需要建立映射的字段与建立好的映射关系的映射id结果dto。
        // eg. mobileSsoUserDto.setBingMappingId("00001");
        // eg. mobileSsoUserDto.setThirdLoginName("zhangsan");

        //返回免登的用户信息
        return mobileSsoUserDto;
    }


    /**
     * 按需实现
     * 用于获取移动接口调用是否成功。
     *
     * @param mobilePlatformConfigDto 需要通过该第三方配置信息中的appId、appKey、appSecret等信息获取token
     * @return 移动接口状态的数据传输对象，包含了接口调用的结果信息。
     * status：布尔值，表示接口调用是否成功。
     * code：接口返回的错误码。
     * msg：接口返回的错误消息。
     * explainInfo：解释性信息，通过调用 explainLinkInfo() 方法获取
     */
    @Override
    public MobileInterfaceStatusDto interfaceStatus(MobilePlatformConfigDto mobilePlatformConfigDto) {
        //创建一个 MobileInterfaceStatusDto 对象 statusDto，并调用 setExplainInfo 方法设置其解释信息（调用 explainLinkInfo() 方法获取相关信息）
        MobileInterfaceStatusDto statusDto = new MobileInterfaceStatusDto();
        statusDto.setExplainInfo(explainLinkInfo());

        //根据token等信息获取响应对象(获取响应对象方法中需要的入参具体看三方文档)
        log.info("接口状态查询结果");
        // 返回状态dto
        return statusDto;
    }

    /**
     * 按需实现
     * 通过移动应用的API获取用户的OpenID，查看三方文档利用移动应用的身份验证和数据查询功能，确保返回正确的用户标识。 若不需要实现，则直接返回null
     * 调用第三方接口获取用户的 openId
     *
     * @param mobilePlatformConfigDto
     * @param dto
     * @return 返回值 (String)：用户在移动应用的OpenID
     */
    @Override
    public String getOpenId(MobilePlatformConfigDto mobilePlatformConfigDto, MobileOpenIdDto dto) {

        // 创建一个包含手机号的参数 map，用于后续的 API 请求
        Map<String, Object> map = new HashMap<>();
        map.put("mobiles", Arrays.asList(dto.getPhoneNumber()));
        // 构建完整的 API 请求 URL

        // 使用自定义工具类实现post方法或调用平台提供的发送post请求的方法创建一个 POST 方法的 HTTP 请求，传入所需的参数，例如： Token、API URL 以及能指定要查的用户的唯一标识的值信息等

        // 执行 HTTP 请求并获取响应体的内容

        // 返回响应结果值中的用户在移动应用的OpenID
        // return result.getData().getUserList().get(0).getUserId();
        return null;
    }

    /**
     * 按需实现 企业微信个人聊天窗口需要通过以下方法来唤起页面的code (可通过获取唤起企业微信code接口获取) 。若不需要实现，则直接返回null
     * 通过调用三方平台提供的 查询发布应用的应用编码接口 来获取launch_code
     *
     * @param mobilePlatformConfigDto 通过 mobilePlatformConfigDto 信息拿到corpId, appId, appKey等信息
     * @param mobileLaunchCodeDto     从这个dto中拿到企业微信提供的获取launch_code接口中需要的请求参数： userId：当前操作者的userid；  single_chat：参数数据结构体
     * @return
     */
    @Override
    public String getLaunchCode(MobilePlatformConfigDto mobilePlatformConfigDto, MobileLaunchCodeDto mobileLaunchCodeDto) {

        return null;
    }
}
