package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.callback.ConnectorCallbackMessageSendService;
import com.seeyon.cip.connector.api.mobile.MobileCallBackProviderService;
import com.seeyon.cip.connector.dto.callback.ConnectorCallbackRequestDto;
import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;
import lombok.extern.slf4j.Slf4j;

/**
 * 统一回调接口实现
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileCallBackProviderServiceImpl implements MobileCallBackProviderService {

    /**
     * 处理回调请求的方法: 三方移动平台有时候需要向V8平台发送回调请求，由V8平台进行相应的处理并将处理消息发送到MQ以供三方平台接受处理后的消息结果
     * @param dto  ConnectorCallbackRequestDto 对象，包含回调请求的各种参数和数据。
     *             dto.getParaMap()：包含三方平台发到V8平台的请求表单中的地址表单参数
     *             dto.getHeaders():请求头
     *             dto.getInputStreamMap(): 文件流
     *
     *             dto.getBody()：XML 格式的回调数据，需要解析并处理
     * @param callbackMessageSendService ConnectorCallbackMessageSendService<BaseDto> 类型的服务，用于V8平台选择异步或者同步方法发送回调处理消息到MQ
     *                                    ConnectorCallbackMessageSendService 为空表示不向 MQ 投递消息
     * @return 自己定义返回值的类型，以下举个例子可作参考：
     *              "success"：表示回调处理成功。
     *              "error"：表示回调处理过程中出现异常。
     *              decrypt：如果是验证回调，返回解密后的字符串。
     */
    @Override
    public Object doCallback(ConnectorCallbackRequestDto dto, ConnectorCallbackMessageSendService callbackMessageSendService) {
        // 具体的回调处理业务逻辑实现

        // 可以通过上面的业务逻辑判断是否回调成功
        // eg. return "false";
        return "success";
        }
    }
