package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.boot.util.JsonUtils;
import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileConfigProviderService;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

/**
 * 配置信息接口实现 <br/>
 * 提供插件基本配置信息
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileConfigProviderServiceImpl implements MobileConfigProviderService {

    /**
     * jsr303校验，对插件基本配置中的字段进行验证<br/>
     * json 的值为 getPageJson() 方法返回的值
     * 检查 jsonMap 中是否包含必要的键 PARAMETER_LOCATION 和 REQUEST_PROPERTIES
     */
    @Override
    public void jsonCheck(String json) {
        log.info(getName()+"开始JSR303检查！");
        Map<String, Object> jsonMap = JsonUtils.toMap(json);
        // 对入参进行校验（按需实现）
    }

    /**
     * 【必填】
     * 插件名称（插件唯一英文标识）<br/>
     * eg. FEI_SHU / DING_TALK
     */
    @Override
    public String getName() {
        return  DemoPlatformConstant.DEMO_MOBILE;
    }

    /**
     * 【必填】
     * 三方客户端中文名称， 需要国际化, json 格式 <br/>
     * eg. "{\"zh_CN\":\"飞书\",\"zh_TW\":\"飛書\",\"en\":\"feishu\"}" <br/>
     * eg. "{\"zh_CN\":\"钉钉\",\"zh_TW\":\"釘釘\",\"en\":\"DingTalk\"}"
     */
    @Override
    public String getTypeCaption() {
        return "{\"zh_CN\":\"移动插件模板\",\"zh_TW\":\"移動插件模板\",\"en\":\"DemoMobile\"}";
    }

    /**
     * 【必填】
     * 插件位置排序
     */
    @Override
    public Integer getSortNo() {
        return 1;
    }

    /**
     * 【必填】
     * 插件配置页面展示的配置内容 json 格式
     *
     * 注意：传入的json中不需要传入 ：企业名称： corpName
     *                           企业编码： corpId
     *                           关联平台应用: platformAppId
     * (前端页面已经固定：企业名称、企业ID、关联平台应用)
     */
    @Override
    public String getPageJson() {
        return "{\"caption\":\"{\\\"zh_CN\\\":\\\"测试插件\\\",\\\"zh_TW\\\":\\\"測試插件\\\",\\\"en\\\":\\\"Testing plugins\\\"}\",\"type\":\"MOBILE_DEMO\",\"extensionProperties\":[{\"label\":\"{\\\"zh_CN\\\":\\\"接入应用名称\\\",\\\"zh_TW\\\":\\\"接入應用名稱\\\",\\\"en\\\":\\\"Access application name\\\"}\",\"name\":\"name\",\"rule\":[{\"required\":true,\"message\":\"接入应用名称不能为空\"}]},{\"label\":\"AppId\",\"name\":\"AppId\",\"rule\":[{\"required\":true,\"message\":\"AppId不能为空\"},{\"type\":\"string\",\"max\":100,\"message\":\"不能超过100个字符\"}]},{\"label\":\"AppSecret\",\"name\":\"AppSecret\",\"rule\":[{\"required\":true,\"message\":\"AppSecret不能为空\"},{\"type\":\"string\",\"max\":100,\"message\":\"不能超过100个字符\"}]}]}";
    }

    /**
     * 【必填】
     * 获取插件的 AppId, SPI 模式下从 json 的配置中获取
     */
    @Override
    public String getAppId(String json) {
        Map<String, Object> map = JsonUtils.toMap(json);
        //从json的配置信息中的key来获取对应的value值并返回
        //注意：map.get("agentId") 中的"agentId"要与 public String getPageJson()方法中 json中 agentId 字段中的key为"name"所对应的value值一致
        return (String) map.get("agentId");
    }

    /**
     * 【必填】
     * 获取  AppSecret, SPI 模式下从 json 的配置中获取
     */
    @Override
    public String getAppSecret(String json) {
        Map<String, Object> map = JsonUtils.toMap(json);
        //从json的配置信息中的key来获取对应的value值并返回
        //注意：map.get("appSecret") 中的"appSecret"要与 public String getPageJson()方法中 json中 appSecret 字段中的key为"name"所对应的value值一致
        return (String) map.get("appSecret");
    }

    /**
     * 【必填】
     * 获取  AppName, SPI 模式下从 json 的配置中获取
     */
    @Override
    public String getAppName(String json) {
        Map<String, Object> map = JsonUtils.toMap(json);
        //从json的配置信息中的key来获取对应的value值并返回
        //注意：map.get("name") 中的"name"要与 public String getPageJson()方法中 json中 企业名称 字段中的key为"corpName"所对应的value值一致
        return (String) map.get("name");
    }

    /**
     * 按需实现
     * 三方插件管理后台链接地址
     */
    @Override
    public String getAdminUrl() {
        // 传入三方插件管理后台的链接地址
        //eg.
        return "http://.......";
    }

    /**
     * 三方移动插件接口地址支持不同环境对应的域名.有些三方移动平台的后台管理地址是固定且唯一的链接。有些三方移动平台的管理后台地址可能有多个，所以对应不同的域名
     * 获取三方平台接口服务域名（多个环境不同时使用）
     *
     * @param mobilePlatformConfigDto 移动插件配置
     * @return String: 三方平台接口服务域名
     */
    @Override
    public String getThirdApplicationDomain(MobilePlatformConfigDto mobilePlatformConfigDto) {
        return MobileConfigProviderService.super.getThirdApplicationDomain(mobilePlatformConfigDto);
    }

    /**
     * 传入三方配置条件：String type, String corpId, String appId, String agentId
     * 该方法需要根据三方移动平台文档查看需要哪些配置参数来获取第三方配置条件
     */
    @Override
    public Map<String, Object> getThirdConfigCondition(String type, String corpId, String appId, String agentId) {

        Map<String, Object> paraMap = new HashMap<>();
        // 例如飞书和钉钉需要以下参数
        // dingtalk
        paraMap.put("type", type);
        paraMap.put("appId", appId);
        return paraMap;
    }

    /**
     * 获取插件 corpId， 如果存在直接返回，如果不存在返回 null
     * 不同插件 corpId  赋值的字段可能不同， 由 spi 自己实现
     */
    @Override
    public String getMobileCorpId(String corpId, String appId, String agentId) {
        return corpId;
    }

    /**
     * 固定返回 true
     */
    @Override
    public boolean isPrivateApp() {
        return true;
    }


}
