package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileOrgSyncBatchProviderService;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.connector.dto.mobile.MobileUserRequestDto;
import com.seeyon.cip.connector.dto.mobile.batch.MobileBatchResultDto;
import com.seeyon.cip.connector.dto.mobile.batch.MobileContactBatchResultDto;
import com.seeyon.cip.connector.dto.mobile.batch.MobileDepartmentBatchSyncDto;
import com.seeyon.cip.connector.dto.mobile.batch.MobileUserBatchSyncDto;
import com.seeyon.cip.connector.dto.mobile.welink.MobileUserDto;
import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description:
 * 批量同步部门(机构、组织)
 * 注意；具体查看三方移动平台是否提供批量组织同步的接口
 * V8平台在实现组织同步时：若三方移动平台提供了批量到同步的接口并在以下实现类中实现了对应的批量同步方法，也在DemoMobileOrgSyncProviderServiceImpl类中实现了单个组织同步的方法的情况下，平台会首选批量组织同步的方法来进行组织同步
 * @Author: lixuh
 * @DateTime: 2024-08-01 14:52
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileOrgSyncBatchProviderServiceImpl implements MobileOrgSyncBatchProviderService {

    /**
     * 批量组织同步
     * @param mobileDepartmentBatchSyncDto
     * @param mobilePlatformConfigDto
     * @return
     */
    @Override
    public String syncUnitBatch(MobileDepartmentBatchSyncDto mobileDepartmentBatchSyncDto, MobilePlatformConfigDto mobilePlatformConfigDto) {

        // 通过 mobilePlatformConfigDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = mobilePlatformConfigDto.getCorpId());
        // eg. String appId = mobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到部门列表信息。然后从列表信息依次中拿到需要同步的组织中的部门信息
        // eg. List<MobileUnitRequestDto> unitDtoList = dto.getUnitDtoList();
//        for (MobileUnitRequestDto requestDto : unitDtoList) {
//            MobileDeptDto mobileDeptDto = new MobileDeptDto();
//            mobileDeptDto.setCorpDeptCode(String.valueOf(requestDto.getId()));
//            mobileDeptDto.setCorpParentCode(String.valueOf(requestDto.getThirdParentId()));
//            mobileDeptDto.setDeptNameCn(convertI18n(requestDto.getName()));
//            list.add(mobileDeptDto);
//        }

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的批量组织同步接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getCreateUnitUri(token), body, MobileDingTalkResponseDto.class);
        // 如果部门同步成功， 若需要在V8平台映射关系，则该组织同步方法的返回值为三方组织平台同步创建好的部门对应的ID。 注意：若不需要映射关系，则只需要返回入参请求中传入的该部门对应的id即可
        log.info("部门批量组织同步成功");
        // return "post请求响应之后的返回值结果对应的唯一标识。例如: result.getJobId();"
        return  "00001";
    }

    /**
     * 批量用户同步
     * @param mobileUserBatchSyncDto
     * @param mobilePlatformConfigDto
     * @return
     */
    @Override
    public String userSyncBatch(MobileUserBatchSyncDto mobileUserBatchSyncDto, MobilePlatformConfigDto mobilePlatformConfigDto) {
        // 通过 mobilePlatformConfigDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = mobilePlatformConfigDto.getCorpId());
        // eg. String appId = mobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到部门列表信息。然后从列表信息依次中拿到需要同步的组织中的部门信息
        // eg. List<MobileUserRequestDto> userDtoList = dto.getUserDtoList();
//        for (MobileUserRequestDto requestDto : userDtoList) {
//            MobileUserDto mobileUserDto = new MobileUserDto();
//            mobileUserDto.setCorpUserId(String.valueOf(requestDto.getId()));
//            mobileUserDto.setMobileNumber(requestDto.getPhoneNumber());
//            mobileUserDto.setUserNameCn(convertI18n(requestDto.getName()));
//            mobileUserDto.setUserEmail(requestDto.getEmail());
//        ......
//        list.add(mobileUserDto);

//        }

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的用户批量同步接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileWeLinkBaseResultDto.BatchSync result = post("url", body, MobileWeLinkBaseResultDto.class);
        log.info("用户批量同步成功");
        // return "post请求响应之后的返回值结果对应的唯一标识。例如: result.getJobId();"
        return  "00001";
    }

    /**
     * 按需实现。若不需要实现直接返回null
     * 批量同步的结果查询
     * @param mobileBatchResultDto
     * @param mobilePlatformConfigDto
     * @return
     */
    @Override
    public MobileContactBatchResultDto syncBatchResult(MobileBatchResultDto mobileBatchResultDto, MobilePlatformConfigDto mobilePlatformConfigDto) {
        // 通过 mobilePlatformConfigDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = mobilePlatformConfigDto.getCorpId());
        // eg. String appId = mobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 使用平台提供的工具类或自定义get请求方法 发送 get 请求(对应的批量同步结果查询地址可以通过相关平台的文档进行查阅)
        return null;
    }
}
