package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileOrgSyncProviderService;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.connector.dto.mobile.MobileUnitRequestDto;
import com.seeyon.cip.connector.dto.mobile.MobileUserRequestDto;
import com.seeyon.cip.connector.dto.mobile.MobileUserResponseDto;

import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;

import lombok.extern.slf4j.Slf4j;


/**
 * 组织同步-单个推送服务接口实现： 将三方移动平台组织机构部门和人员同步到我们在三方移动平台创建好的应用中对应的通讯录中
 * 注意：批量组织同步 和 单个组织同步 两个类是互斥的。 如果有批量同步的实现，则默认会先走批量组织同步
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileOrgSyncProviderServiceImpl implements MobileOrgSyncProviderService {

    /**
     * 组织中的部门同步:支持所选择的同步机构组织中的部门数据同步至钉钉通讯录中
     * @param dto : (通过组织信息拿到需要同步的组织中的部门信息)：根据移动平台对应接口文档查看必填参数，例如：钉钉必填值为：部门名称、父部门ID。
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     * @return
     */
    @Override
    public Long syncUnit(MobileUnitRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 通过组织信息拿到需要同步的组织中的部门信息
        // eg. String name = dto.getName();

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的创建部门信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getCreateUnitUri(token), body, MobileDingTalkResponseDto.class);
        // 如果部门同步成功， 若需要在V8平台映射关系，则该组织同步方法的返回值为三方组织平台同步创建好的部门对应的ID。 注意：若不需要映射关系，则只需要返回入参请求中传入的该部门对应的id即可
        log.info("部门同步成功");

        return 123456001L;
    }


    /**
     * 更新组织中的部门信息:实现了向移动平台发送请求来更新配置信息中指定的组织的部门信息
     * @param dto : (通过组织信息拿到需要更新的组织中的部门信息)：其中必须传入三方平台组织部门对应的ID（因为需要通过此id来找到在三方平台中我们要更新哪个部门的信息）
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     * @return
     */
    @Override
    public void updateUnit(MobileUnitRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 通过组织信息拿到需要更新的组织中的部门信息
        // eg. String name = dto.getName();

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的更新部门信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getUpdateUnitUri(token), body, MobileDingTalkResponseDto.class);
        log.info("部门同步成功");
    }

    /**
     * 获取三方平台组织中的部门信息详情：实现了向移动平台发送请求来查询据配置信息中指定的组织的部门信息详情
     * @param dto : (通过组织信息拿到需要查询的部门的三方id（因为需要通过此id来找到在三方平台中我们要查询的哪个部门的信息）
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     * @return 三方平台组织部门对应的ID
     */
    @Override
    public String getUnit(MobileUnitRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息信息拿到需要查询详情的组织中的部门对应的唯一标识
        // eg. String id = dto.getThirdId());

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的查询部门信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getUnitUri(token), body, MobileDingTalkResponseDto.class);

        // 如果部门同步操作失败，根据不同情况，处理不同的异常或情况。如果部门查询成功，返回部门详情信息

        log.info("查询到部门详情信息成功");
        // 返回值为三方组织平台同步创建好的部门对应的新ID
        return String.valueOf(123456001L);
    }

    /**
     * 删除组织中的部门信息：实现了向移动平台发送请求来删除据配置信息中指定的组织的部门信息
     * @param dto : (通过组织信息拿到需要删除的部门的三方id（因为需要通过此id来找到在三方平台中我们要删除的哪个部门的信息）
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     */
    @Override
    public void removeUnit(MobileUnitRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到需要删除的组织中的部门对应的唯一标识
        // eg. String id = dto.getThirdId());

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的删除部门信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.removeUnitUri(token), body, MobileDingTalkResponseDto.class);
        log.info("成功删除部门信息");
    }

    /**
     * 组织中的人员同步:支持所选择的同步机构组织中的人员数据同步至三方平台的通讯录中
     * @param dto 需要同步的用户信息。根据移动平台对应接口文档查看必填参数，例如：钉钉必填值为：用户姓名、用户手机号、用户所属部门列表。
     * @param configDto  第三方平台配置信息：appId、appKey、appSecret、corpId...
     * @return 用户 id (注意:此处返回的用户id并不是三方平台创建的用户对应的三方id。而是同步用户信息请求入参中对应的内部用户id) eg. return String.valueOf(dto.getId());
     */
    @Override
    public String syncUser(MobileUserRequestDto dto, MobilePlatformConfigDto configDto) {
        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到需要同步的组织中的人员信息
        // eg. String name = dto.getName();
        // eg. String email = dto.getEmail();

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的接口请求地址可以通过相关平台的文档进行查阅)，将用户信息以 JSON 格式发送到移动平台的创建用户接口，并返回结
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getCreateUsrUri(token), body, MobileDingTalkResponseDto.class);
        // 如果人员同步操作失败，根据不同情况，处理不同的异常或情况。如果人员同步成功，返回同步人员的唯一标识
        log.info("人员同步操作执行完毕");
        return String.valueOf(01);
    }


    /**
     * 更新三方平台中组织中的用户信息：
     * @param dto (通过传入的用户信息dto对象拿到需要更新的用户信息具体值)：其中必须传入三方平台组织用户对应的三方唯一标识：userid（因为需要通过此userid来找到在三方平台中我们要更新哪个用户的信息）
     * @param configDto  第三方平台配置信息：appId、appKey、appSecret、corpId...
     * @return 用户 id (注意:此处返回的用户id并不是三方平台创建的用户对应的三方id。而是同步用户信息请求入参中对应的内部用户id) eg. return String.valueOf(dto.getId());
     */
    @Override
    public String updateUser(MobileUserRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 通过组织信息拿到需要更新的组织中的用户信息
        // eg. String name = dto.getName();
        // eg. String phoneNumber = dto.getPhoneNumber()

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的更新用户信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getUpdateUsrtUri(token), body, MobileDingTalkResponseDto.class);
        log.info("用户信息更新成功");
        return String.valueOf(dto.getId());
    }

    /**
     * 获取三方平台组织中的用户信息详情：实现了向移动平台发送请求来查询据配置信息中指定用户的信息详情
     * @param dto : (通过用户信息dto拿到需要查询的用户的三方userid（因为需要通过此userid来找到在三方平台中我们要查询的哪个用户的信息）
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     * @return 三方平台返回的用户信息dto对象
     */
    @Override
    public MobileUserResponseDto getUser(MobileUserRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到需要查询的组织中的用户唯一标识
        // eg. String id = dto.getUserId());

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的查询部门信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.getUnitUri(token), body, MobileDingTalkResponseDto.class);

        // 如果部门同步操作失败，根据不同情况，处理不同的异常或情况。如果部门查询成功，返回部门详情信息
        MobileUserResponseDto responseDto = new MobileUserResponseDto();
        responseDto.setUserId("001");
        log.info("查询到的用户详情信息");
        return responseDto;

    }


    /**
     * 删除组织中的用户信息
     * @param dto : (通过用户信息dto拿到需要删除的用户的三方userid（因为需要通过此userid来找到在三方平台中我们要删除的哪个用户的信息）
     * @param configDto: (配置信息参数) appId、appKey、appSecret、corpId...
     * @return 三方平台返回的用户信息dto对象
     */
    @Override
    public MobileUserResponseDto removeUser(MobileUserRequestDto dto, MobilePlatformConfigDto configDto) {

        //  通过配置信息拿到 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 通过组织信息拿到需要删除的组织中的用户对应的唯一标识
        // eg. String id = dto.getUserId());

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的删除用户信息接口请求地址可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(DingTalkConstants.removeUsrUri(token), body, MobileDingTalkResponseDto.class);
        MobileUserResponseDto responseDto = new MobileUserResponseDto();
        responseDto.setUserId("001");
        log.info("删除用户信息成功");
        return responseDto;
    }
}
