package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileOrgSyncPullProviderService;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.connector.dto.mobile.MobileSyncPullOrgResponseDto;
import com.seeyon.cip.connector.dto.mobile.MobileSyncPullUserResponseDto;
import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.List;

/**
 * @Description: 组织同步-批量拉取
 * @Author: lixuh
 * @DateTime: 2024-07-29 15:49
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileOrgSyncPullProviderServiceImpl implements MobileOrgSyncPullProviderService {
    /**
     * 增量拉取组织信息
     * latestVersion = 1 时全量拉取，其它值时 增量拉取
     * 拉取组织信息， latestVersion表示偏移量。 如果 latestVersion = 1 则从三方移动平台对应的组织信息中的第一页开始拉取， 如果不等于1，从 latestVersion 开始的位置进行拉取
     */
    @Override
    public List<MobileSyncPullOrgResponseDto> listSyncOrg(MobilePlatformConfigDto configDto, String latestVersion) {
        if ("1".equals(latestVersion)) {
            // 全量拉取组织信息的逻辑
            return fetchAllOrgData(configDto);
        } else {
            // 增量拉取组织信息的逻辑，比如根据最新版本号拉取增量数据
            return fetchIncrementalOrgData(configDto, latestVersion);
        }
    }

    /**
     * 查询用户信息， latestVersion表示偏移量。 如果 latestVersion = 1 则从三方移动平台对应的用户中的第一页开始拉取， 如果不等于1，从 latestVersion 开始的位置进行拉取
     * latestVersion = 1 时全量，其它值是 增量
     */
    @Override
    public List<MobileSyncPullUserResponseDto> listSyncUser(MobilePlatformConfigDto configDto, String latestVersion) {
        if ("1".equals(latestVersion)) {
            // 全量拉取用户信息的逻辑
            return fetchAllUserData(configDto);
        } else {
            // 增量拉取用户信息的逻辑，比如根据最新版本号拉取增量数据
            return fetchIncrementalUserData(configDto, latestVersion);
        }
    }

    // 模拟全量拉取组织信息的方法
    private List<MobileSyncPullOrgResponseDto> fetchAllOrgData(MobilePlatformConfigDto configDto) {
        // 实际的数据获取逻辑
        // 这里假设直接返回一个空列表作为示例
        return new ArrayList<>();
    }

    // 模拟增量拉取组织信息的方法
    private List<MobileSyncPullOrgResponseDto> fetchIncrementalOrgData(MobilePlatformConfigDto configDto, String latestVersion) {
        // 实际的增量数据获取逻辑
        // 这里假设直接返回一个空列表作为示例
        return new ArrayList<>();
    }

    // 模拟全量拉取用户信息的方法
    private List<MobileSyncPullUserResponseDto> fetchAllUserData(MobilePlatformConfigDto configDto) {
        // 实际的数据获取逻辑
        // 这里假设直接返回一个空列表作为示例
        return new ArrayList<>();
    }

    // 模拟增量拉取用户信息的方法
    private List<MobileSyncPullUserResponseDto> fetchIncrementalUserData(MobilePlatformConfigDto configDto, String latestVersion) {
        // 实际的增量数据获取逻辑
        // 这里假设直接返回一个空列表作为示例
        return new ArrayList<>();
    }
}
