package com.seeyon.cip.spi.mobile.demo;

import com.seeyon.cip.connector.annotation.ConnectorChannelRouter;
import com.seeyon.cip.connector.api.mobile.MobileTodoProviderService;
import com.seeyon.cip.connector.dto.mobile.MobilePlatformConfigDto;
import com.seeyon.cip.connector.dto.mobile.MobileTodoRequestDto;
import com.seeyon.cip.spi.mobile.demo.constant.DemoPlatformConstant;
import lombok.extern.slf4j.Slf4j;


/**
 * 待办服务接口实现：将V8平台前台网页展示的待办信息可以在三方移动平台显示并修改
 */
@Slf4j
@ConnectorChannelRouter(DemoPlatformConstant.DEMO_MOBILE)
public class DemoMobileTodoProviderServiceImpl implements MobileTodoProviderService {

    /**
     * 该方法用于在移动平台上创建待办事项
     * @param mobilePluginPlatformRequestDto 配置信息：需要从这些信息中获取 appkey、appId、appSecret等信息来生成token
     * @param mobileTodoRequestDto 包含待办事项创建请求信息的数据传输对象
     * @return
     */
    @Override
    public String createTodo(MobilePlatformConfigDto mobilePluginPlatformRequestDto, MobileTodoRequestDto mobileTodoRequestDto) {

        // 通过 mobilePluginPlatformRequestDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = MobilePlatformConfigDto.getCorpId());
        // eg. String appId = MobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 封装请求参数：具体封装方式需要结合三方移动平台的待办接口文档的请求参数规定

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的创建待办任务接口请求地址url可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(url, body, MobileDingTalkResponseDto.class);
        // 创建待办事项。返回创建成功后的待办事项的标识符或状态信息
        log.info("待办事项创建成功");
        //返回创建的待办事项的id值(String类型)
        //eg.
        return "001";

    }

    /**
     * 通过待办信息的唯一标识来 更新待办信息（只更新内容，不包含完成状态）
     */
    @Override
    public void updateTodo(MobilePlatformConfigDto configDto, MobileTodoRequestDto mobileTodoRequestDto) {
        // 通过 mobilePluginPlatformRequestDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = MobilePlatformConfigDto.getCorpId());
        // eg. String appId = MobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);

        // 封装请求参数：具体封装方式需要结合三方移动平台的待办接口文档的请求参数规定

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的更新待办任务接口请求地址url可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(url, body, MobileDingTalkResponseDto.class);

        // 更新待办事项
        log.info("待办更新成功");
    }

    /**
     * 通过待办 id 更新待办为已完成
     */
    @Override
    public void doneTodo(MobilePlatformConfigDto configDto, Long userId, String taskId) {
        // 通过 mobilePluginPlatformRequestDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = MobilePlatformConfigDto.getCorpId());
        // eg. String appId = MobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 封装请求参数：具体封装方式需要结合三方移动平台的待办接口文档的请求参数规定

        // 使用平台提供的工具类或自定义post请求方法 发送 POST 请求(对应的更新待办任务接口请求地址url可以通过相关平台的文档进行查阅)
        // eg. MobileDingTalkResponseDto result = post(url, body, MobileDingTalkResponseDto.class);
        // 更新待办任务并将待办任务的状态改为已完成 例如:待办任务状态定义为布尔类型：true代表该待办任务已完成
    }

    /**
     * 通过待办信息的唯一标识来 更删除办任务信息
     */
    @Override
    public void deleteTodo(MobilePlatformConfigDto configDto, Long aLong, String taskId) {
        // 通过 mobilePluginPlatformRequestDto 信息拿到corpId, appId, appKey等信息
        // eg. String corpId = MobilePlatformConfigDto.getCorpId());
        // eg. String appId = MobilePlatformConfigDto.getAppId());
        //  通过配置信息拿到的 appId、 appKey、appSecret、agentId等信息，查看三方平台文档生成获取token访问凭证
        // eg. String token = getTokenByCode(appId, appKeyappSecret);
        // 通过代办唯一标识和 生成的token来找到待办事项并删除
        log.info("待办删除成功");

    }

}
